@@ -17,14 +17,15 @@ qx.Class.define("callbackery.ui.Card", {
      */
     construct: function(pluginName, cardCfg, actions, buttonMap, parentForm) {
         this.base(arguments);
-        this._formCfg     = cardCfg;
+        this._cardCfg     = cardCfg;
         this.__actions    = actions;
         this.__parentForm = parentForm;
         this.__buttonMap  = buttonMap;
         this.__pluginName = pluginName;
+        this._formCfg = {};
+        this.__dataCache = {};
 
         this.__buildForm();
-        this.__dataCache = {};
     },
     properties: {
         appearance: {
@@ -34,6 +35,7 @@ qx.Class.define("callbackery.ui.Card", {
     },
     events:  {reloadData: 'qx.event.type.Event'},
     members: {
+        _cardCfg     : null,
         _formCfg     : null,
         __actions    : null,
         __dataCache  : null,
@@ -43,16 +45,22 @@ qx.Class.define("callbackery.ui.Card", {
         __parentForm : null,
 
         setData: function(data) {
-            var fld = this.__fields;
-            var last = this.__dataCache;
-            last['id'] = data.id;
+            var cardCfg = this._cardCfg;
+            var fld     = this.__fields;
+            var last    = this.__dataCache;
+            last.id     = data.id;
             for (var k in fld) {
                 if (data[k] !== last[k]) {
-                    if (data[k] == null) {
-                        fld[k].setValue('');
+                    if (fld[k].setModelSelection) { // SelectBox
+                        fld[k].setModelSelection([data[k]]);
                     }
-                    else {
-                        fld[k].setValue(String(this.xtr(data[k]) || ''));
+                    else { // e.g. TextField
+                        if (data[k] == null) {
+                            fld[k].setValue('');
+                        }
+                        else {
+                            fld[k].setValue(String(this.xtr(data[k]) || ''));
+                        }
                     }
                     last[k] = data[k];
                 }
@@ -73,9 +81,13 @@ qx.Class.define("callbackery.ui.Card", {
 
         __buildForm: function() {
             var fld     = this.__fields = {};
-            var cardCfg = this._formCfg;
+            var cardCfg = this._cardCfg;
             var formCfg = cardCfg.form;
 
+            if (! formCfg) {
+                console.error('no formCfg: cardCfg=', cardCfg);
+                return;
+            }
             // set layout
             var layoutCfg   = cardCfg.layout;
             var layoutClass = qx.ui.layout.Grid; // default
@@ -95,7 +107,6 @@ qx.Class.define("callbackery.ui.Card", {
             formCfg.forEach(function(cfg) {
                 var labelCfg = cfg.label;
                 var fieldCfg = cfg.field;
-
                 // add label
                 if (labelCfg) {
                     var label = new qx.ui.basic.Label(labelCfg.value).set({
@@ -111,17 +122,50 @@ qx.Class.define("callbackery.ui.Card", {
 
                 // add field
                 if (fieldCfg) {
-                    var fieldClass = qx.ui.form.TextField; // default
-                    if (fieldCfg.class) 
-                        fieldClass = qx.Bootstrap.getByName(fieldCfg.class);
+                    var key = fieldCfg.key;
+                    this._formCfg[key] = fieldCfg;
+                    var className = fieldCfg.class ? fieldCfg.class : 'TextField';
+                    if (! className.match(/^qx/)) {
+                        className = 'qx.ui.form.' + className;
+                    }
+                    var fieldClass = qx.Bootstrap.getByName(className);
                     var field = new fieldClass;
-                    if (fieldCfg.set)
+                    if (fieldCfg.set) {
                         field.set(fieldCfg.set);
-                    if (! field.getReadOnly()) {
-                        field.addListener('changeValue', this.__updateEntry, this);
+                    }
+                    var event;
+                    if (field.setLiveUpdate && ! field.getReadOnly()) { // TextField
                         field.setLiveUpdate(true);
+                        event = 'changeValue';
+                    }
+                    if (field.setModelSelection) { // SelectBox
+                        if (fieldCfg.items) {
+                            for (let item of fieldCfg.items) {
+                                field.add(new qx.ui.form.ListItem(this.xtr(item[1]), null, item[0]));
+                            }
+                        }
+                        event = 'changeSelection';
+                    }
+                    if (event) {
+                        field.addListener(event, (e) => {
+                            let data = e.getData();
+                            let value;
+                            if (Array.isArray(data)) {
+                                value = data[0].getModel();
+                            }
+                            else {
+                                value = data;
+                            }
+                            var rpc = callbackery.data.Server.getInstance();
+                            this.__parentForm.setSelection({ data : this.__dataCache, key : fieldCfg.key, value : value });
+                            if (this.__buttonMap['updateEntry']) {
+                                this.__buttonMap['updateEntry'].execute();
+                            }
+                            else {
+                                console.warn('No method for updateEntry');
+                            }
+                        });
                     }
-                    
                     this._add(field, fieldCfg.addSet);
                     fld[fieldCfg.key] = field;
                 }
@@ -137,14 +181,6 @@ qx.Class.define("callbackery.ui.Card", {
                 }, this);
                 this._add(btn, action.cardAddSet);
             }, this);
-        },
-
-        __updateEntry: function(e) {
-            var value = e.getData();
-            var rpc = callbackery.data.Server.getInstance();
-            this.__parentForm.setSelection({ data : this.__dataCache, newValue : value });
-            this.__buttonMap['updateEntry'].execute();
         }
-
     }
 });
